==> haskell-statistics-0.14.0.2-72-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: statistics
version: 0.14.0.2
id: statistics-0.14.0.2-8T5xHWDyoYjAJzyQTFh3Yj
key: statistics-0.14.0.2-8T5xHWDyoYjAJzyQTFh3Yj
license: BSD-2-Clause
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/statistics
synopsis: A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
    samples.
category: Math, Statistics
abi: 65a90189fa4f856ba3d54a1e7d216f04
exposed: True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
    Statistics.Test.ChiSquared Statistics.Test.KolmogorovSmirnov
    Statistics.Test.KruskalWallis Statistics.Test.MannWhitneyU
    Statistics.Test.StudentT Statistics.Test.Types
    Statistics.Test.WilcoxonT Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Sample.Internal Statistics.Test.Internal
                Statistics.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/statistics-0.14.0.2
hs-libraries: HSstatistics-0.14.0.2-8T5xHWDyoYjAJzyQTFh3Yj
depends:
    aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV base-4.11.1.0
    base-orphans-0.8-3sF6oREckV1L10hzXC2CHH binary-0.8.5.1
    deepseq-1.4.3.0 erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS
    math-functions-0.3.0.2-4TeUD9HzvwXAMjvZvu2qup
    monad-par-0.3.4.8-DDL1D8164QlFk7EDVxaEbx
    mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-algorithms-0.7.0.4-5IwVwgBYaiLHifekCoPTVl
    vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
abi-depends: aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.8-3sF6oREckV1L10hzXC2CHH=070878b14ffeb7fb78d1dad8024b95cb
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS=8e3912e1d1724c98e62b099f34079dd1
             math-functions-0.3.0.2-4TeUD9HzvwXAMjvZvu2qup=835d1e98e5d00531fd31c6048fc36b0b
             monad-par-0.3.4.8-DDL1D8164QlFk7EDVxaEbx=3f1bdb3b83ae7f2565aca5375a1900ce
             mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue=13b0a70bc032f17e1af67dfb839e49c8
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             vector-algorithms-0.7.0.4-5IwVwgBYaiLHifekCoPTVl=f933dd42d5669d79615d6ae8d22a24cf
             vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw=8f69a3d65bc98dbbc58625401f1b4c42
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html: /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statistics-0.14.0.2-74-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: statistics
version: 0.14.0.2
id: statistics-0.14.0.2-2VKaAri2TiD70l21rd7UCP
key: statistics-0.14.0.2-2VKaAri2TiD70l21rd7UCP
license: BSD-2-Clause
copyright: 2009-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/statistics
synopsis: A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.
    .
    The library'\''s facilities can be divided into four broad categories:
    .
    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)
    .
    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.
    .
    * Random variate generation under several different distributions.
    .
    * Common statistical tests for significant differences between
    samples.
category: Math, Statistics
abi: 74994597b723985d585bdae290c15138
exposed: True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Math.RootFinding Statistics.Matrix
    Statistics.Matrix.Algorithms Statistics.Matrix.Mutable
    Statistics.Matrix.Types Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
    Statistics.Test.ChiSquared Statistics.Test.KolmogorovSmirnov
    Statistics.Test.KruskalWallis Statistics.Test.MannWhitneyU
    Statistics.Test.StudentT Statistics.Test.Types
    Statistics.Test.WilcoxonT Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Sample.Internal Statistics.Test.Internal
                Statistics.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/statistics-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/statistics-0.14.0.2
hs-libraries: HSstatistics-0.14.0.2-2VKaAri2TiD70l21rd7UCP
depends:
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL base-4.11.1.0
    base-orphans-0.8-4sD00YChBlrBgDwkujHWZz binary-0.8.5.1
    deepseq-1.4.3.0 erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS
    math-functions-0.3.0.2-4TeUD9HzvwXAMjvZvu2qup
    monad-par-0.3.4.8-DDL1D8164QlFk7EDVxaEbx
    mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    vector-algorithms-0.8.0.0-GDWc64DH7nJ72e6auaL2EB
    vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
abi-depends: aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-orphans-0.8-4sD00YChBlrBgDwkujHWZz=0dd735d891c827017f35adf5b579ce37
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             erf-2.0.0.0-DoVcmknp6yaG2oYcmiezYS=8e3912e1d1724c98e62b099f34079dd1
             math-functions-0.3.0.2-4TeUD9HzvwXAMjvZvu2qup=835d1e98e5d00531fd31c6048fc36b0b
             monad-par-0.3.4.8-DDL1D8164QlFk7EDVxaEbx=3f1bdb3b83ae7f2565aca5375a1900ce
             mwc-random-0.14.0.0-G3WB7Ur1ZQJ5WcBeaI4Sue=13b0a70bc032f17e1af67dfb839e49c8
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             vector-algorithms-0.8.0.0-GDWc64DH7nJ72e6auaL2EB=79f5893cb768f70884e065717b287eff
             vector-th-unbox-0.2.1.6-5wEe6hRA1hMRE4Y3gV5Tw=8f69a3d65bc98dbbc58625401f1b4c42
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
haddock-interfaces: /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html: /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
